# Clintermission - Python CLI Intermission Library
`clintermission` is a small Python library designed to quickly get a selection
of a single or multiple items from a user. The menu shown is explicitly not a
fullscreen menu so the user can use information in their console history to
make a selection.

The menu is implemented by using `prompt-toolkit`'s `Buffer` class.

Inspired by [go promptui](https://github.com/manifoldco/promptui).
